@@ -1,8 +1,9 @@
 from os import path
 
 import pytest
+import respx
 
-from pysjtu.ocr import LegacyRecognizer, NNRecognizer
+from pysjtu.ocr import LegacyRecognizer, NNRecognizer, JCSSRecognizer
 
 CAPTCHA_DIR = path.join(path.dirname(path.abspath(__file__)), 'resources/captcha')
 MODEL_FILE = path.join(path.abspath("."), 'svm_model.onnx')
@@ -16,3 +17,9 @@ NN_MODEL_FILE = path.join(path.abspath("."), 'nn_model.onnx')
 ])
 def test_recognizer(predictor, captcha):
     assert predictor.recognize(open(path.join(CAPTCHA_DIR, captcha + ".jpg"), mode="rb").read()) == captcha
+
+@respx.mock
+def test_jcss_recognizer():
+    respx.post("https://jcss.lightquantum.me", content='{"status":"success","data":{"prediction":"gbmke","elapsed_time":2}}')
+    predictor = JCSSRecognizer()
+    assert predictor.recognize(b'fbkfbkfbk') == "gbmke"
\ No newline at end of file
